"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.configurationGenerator = configurationGenerator;
exports.addTargetToProject = addTargetToProject;
const devkit_1 = require("@nx/devkit");
const constants_js_1 = require("../../internal/constants.js");
const code_pushup_config_js_1 = require("./code-pushup-config.js");
async function configurationGenerator(tree, options) {
    const projectConfiguration = (0, devkit_1.readProjectConfiguration)(tree, options.project);
    const { skipConfig, skipTarget, skipFormat } = options;
    if (skipConfig === true) {
        devkit_1.logger.info('Skip config file creation');
    }
    else {
        (0, code_pushup_config_js_1.generateCodePushupConfig)(tree, projectConfiguration.root);
    }
    if (skipTarget === true) {
        devkit_1.logger.info('Skip adding target to project');
    }
    else {
        addTargetToProject(tree, projectConfiguration, options);
    }
    if (skipFormat === true) {
        devkit_1.logger.info('Skip formatting files');
    }
    else {
        await (0, devkit_1.formatFiles)(tree);
    }
}
function addTargetToProject(tree, projectConfiguration, options) {
    const { targets } = projectConfiguration;
    const { targetName, project } = options;
    const codePushupTargetConfig = {
        executor: `${constants_js_1.PACKAGE_NAME}:cli`,
    };
    (0, devkit_1.updateProjectConfiguration)(tree, project, {
        ...projectConfiguration,
        targets: {
            ...targets,
            [targetName ?? constants_js_1.DEFAULT_TARGET_NAME]: codePushupTargetConfig,
        },
    });
}
exports.default = configurationGenerator;
//# sourceMappingURL=generator.js.map